@@ -1,6 +1,6 @@
 package Log::Log4perl::Appender::Chunk::Store::S3;
 {
-  $Log::Log4perl::Appender::Chunk::Store::S3::VERSION = '0.004';
+  $Log::Log4perl::Appender::Chunk::Store::S3::VERSION = '0.005';
 }
 
 use Moose;
@@ -18,6 +18,7 @@ use POSIX 'setsid';
 use DateTime;
 
 use Log::Log4perl;
+my $LOGGER = Log::Log4perl->get_logger();
 
 sub BEGIN{
     eval "require Net::Amazon::S3::Client;";
@@ -35,6 +36,8 @@ has 'aws_access_key_id' => ( is => 'ro' , isa => 'Str', required => 1 );
 has 'aws_secret_access_key' => ( is => 'ro' , isa => 'Str' , required => 1);
 has 'retry' => ( is => 'ro' , isa => 'Bool' , required => 1 , default => 1);
 
+has 'log_auth_links' => ( is => 'ro' , isa => 'Bool' , required => 1, default => 0);
+
 
 # Single object properties.
 
@@ -62,11 +65,78 @@ Log::Log4perl::Appender::Chunk::Store::S3 - Store chunks in an S3 bucket
 
 =head1 SYNOPSIS
 
-See L<Log::Log4perl::Appender::Chunk>'s synopis for an example.
+Example:
+
+  # Built-in store class S3
+  log4perl.appender.Chunk.store_class=S3
+  # S3 Mandatory options
+  log4perl.appender.Chunk.store_args.bucket_name=MyLogChunks
+  log4perl.appender.Chunk.store_args.aws_access_key_id=YourAWSAccessKey
+  log4perl.appender.Chunk.store_args.aws_secret_access_key=YourAWS
+
+
+See L<Log::Log4perl::Appender::Chunk>'s synopsis for a more complete example.
+
+=head1 OPTIONS
+
+=over
+
+=item bucket_name
+
+Mandatory. Name of the Amazon S3 bucket to store the log chunks.
+
+=item aws_access_key_id
+
+Mandatory. Your S3 access key ID. See L<Net::Amazon::S3>
+
+=item asw_secret_acccess_key
+
+Mandatory. Your S3 Secret access key. See L<Net::Amazon::S3>
+
+=item retry
+
+Optional. See L<Net::Amazon::S3>
+
+Defaults to true.
+
+=item acl_short
+
+Optional. Shortcut to commonly used ACL rules. Valid values are:
+private public-read public-read-write authenticated-read.
+
+See L<https://metacpan.org/source/PFIG/Net-Amazon-S3-0.59/lib/Net/Amazon/S3/Client/Object.pm>
+
+Defaults to undef, meaning your Amazon Bucket's default will be applied. That's probably
+the most desirable behaviour.
+
+=item expires_in_days
+
+Optional. Amount of days in the future stored chunks should expire. No value means never.
+
+Defaults to undef.
+
+=item vivify_bucket
+
+Optional. If true, this writer will attempt to vivify a non existing bucket name if possible.
+
+Defaults to false.
+
+=item log_auth_links
+
+Optional. If true, this writer will log (at DEBUG level) the authenticated links to the stored chunks
+in other log appenders.
+
+Use with care as this could lead to confidential information leakage.
+
+Defaults to false.
+
+=back
+
+=head1 METHODS
 
 =head2 clone
 
-Returns a fresh copy of myself based on the same settings.
+Returns a fresh copy of myself based on the same settings. Mainly used internaly.
 
 Usage:
 
@@ -82,7 +152,8 @@ sub clone{
                              retry => $self->retry(),
                              acl_short => $self->acl_short(),
                              expires_in_days => $self->expires_in_days(),
-                             vivify_bucket => $self->vivify_bucket()
+                             vivify_bucket => $self->vivify_bucket(),
+                             log_auth_links => $self->log_auth_links(),
                             });
 }
 
@@ -142,6 +213,9 @@ sub store{
                                             $expires_ymd ? ( expires => $expires_ymd ) : (),
                                           );
     $s3object->put($big_message);
+    if( $self->log_auth_links() ){
+        $LOGGER->debug("Stored log chunk in ".$s3object->query_string_authentication_uri());
+    }
     exit(0);
 }
 
